@@ -18,17 +18,6 @@ my $pubnub = PubNub::PubSub->new(
     sub_key  => $ENV{PUBNUB_SUB_KEY} || 'sub-c-a66b65f2-2d96-11e4-875c-02ee2ddab7fe',
     channel  => $ENV{PUBNUB_CHANNEL} || 'sandbox',
     # debug    => 1,
-    publish_callback => sub {
-        my ($data) = @_;
-
-        print Dumper(\$data);
-
-        $got_message++;
-        if ($got_message == $total_message or $got_message % 1000 == 0) {
-            my $duration = time() - $start_time;
-            print "$got_message spent $duration.\n";
-        }
-    }
 );
 
 print "Total sending $total_message\n";
@@ -36,7 +25,20 @@ my @messages;
 foreach (1 .. $total_message) {
     push @messages, "message" . $_;;
 }
-$pubnub->publish({ messages => \@messages });
+$pubnub->publish({
+    messages => \@messages,
+    callback => sub {
+        my ($res) = @_;
+
+        print Dumper(\$res->json);
+
+        $got_message++;
+        if ($got_message == $total_message or $got_message % 1000 == 0) {
+            my $duration = time() - $start_time;
+            print "$got_message spent $duration.\n";
+        }
+    }
+});
 
 my $duration = time() - $start_time;
 print "Spent $duration.\n";
